@@ -41,7 +41,7 @@ class HTTPSConnection(httplib.HTTPSConnection):
         subjectAltName not handled
         """
         sock = socket.create_connection((self.host, self.port), self.timeout)
-        ca_path = os.path.join(os.path.dirname(__file__), 'GeoTrust_Primary_CA.pem')
+        ca_path = os.path.join(os.path.dirname(__file__), 'root_ca.pem')
         try:
             self.sock = ssl.wrap_socket(sock, self.key_file, self.cert_file,
                     cert_reqs=ssl.CERT_REQUIRED,
